Learn R Programming

corrMCT (version 0.2.0)

corr.Bonferroni: ICC adjusted Bonferroni method

Description

corr.Bonferroni performs the ICC adjusted Bonferroni method proposed by Shi, Pavey, and Carter(2012). Power law approximation by r is tricky, suggested options was listed in the paper.

Usage

corr.Bonferroni(p, ICC, r = 0, alpha = 0.05)

Value

A numeric vector of adjusted p-values.

Arguments

p

A numeric vector. A length \(m\) P-value vector from multiple tests.

ICC

A number. Intraclass correlation correction factor, a real number between (0, 1).

r

A number. Tuning parameter for g** between (0, 1). Default r=0.

alpha

A real number. \(1-\alpha\) is the confidence level, alpha must between (0, 1).

References

Shi, Q., Pavey, E. S., & Carter, R. E. (2012). Bonferroni‐based correction factor for multiple, correlated endpoints. Pharmaceutical statistics, 11(4), 300-309.

Examples

Run this code
m <- 10
corr.Bonferroni(
  p = runif(m),
  ICC = 0.3
)

Run the code above in your browser using DataLab